Builder

Struct Builder 

pub struct Builder<T, S, O> { /* private fields */ }
Builder pattern for creating a crate::ddk::DlcDevKit process.

Implementations

Source

impl<T: Transport, S: Storage, O: Oracle> Builder<T, S, O>

pub fn new() -> Self

Create a new, default DDK builder.

pub fn set_name(&mut self, name: &str) -> &mut Self

Set the name of the DDK process. Used as an identifier for the process created. Creates a directory for the process with the name specifed. All file-based components will be stored in a directory under the storage path set in the DdkConfig and the name. If no name is set, defaults to a generated uuid.

pub fn set_transport(&mut self, transport: Arc<T>) -> &mut Self

The communication layer of DDK. Type MUST implement crate::Transport. Transport sets up listeners, communicates with counterparties, and passes DLC messages to the Manager.

pub fn set_storage(&mut self, storage: Arc<S>) -> &mut Self

DLC contract storage. Storage is used by the ddk_manager::manager::Manager to create, update, retrieve, and delete contracts. MUST implement crate::Storage.

pub fn set_oracle(&mut self, oracle: Arc<O>) -> &mut Self

Oracle implementation for the ddk_manager::manager::Manager to retrieve oracle attestations and announcements. MUST implement crate::Oracle.

pub fn set_contract_address_generator( &mut self, contract_address_generator: Arc<dyn AddressGenerator + Send + Sync + 'static>, ) -> &mut Self

Wallet implementation for the ddk_manager::manager::Manager to retrieve wallet keys and sign transactions. For now, just uses the DlcDevKitWallet implementation. Optionally can use a custom address generation.

pub fn set_esplora_host(&mut self, host: String) -> &mut Self

Set the esplora server to connect to.

pub fn set_network(&mut self, network: Network) -> &mut Self

Set the network DDK connects to.

pub fn set_seed_bytes( &mut self, seed_config: SeedConfig, ) -> Result<&mut Self, BuilderError>

Set the seed bytes for the wallet.

pub fn set_logger(&mut self, logger: Arc<Logger>) -> &mut Self

Set the logger for the DDK instance.

pub async fn finish(&self) -> Result<DlcDevKit<T, S, O>, Error>

Builds the DlcDevKit instance. Fails if any components are missing.