Module error

Module error 

DDK error types

Enums

BuilderError
Errors that can occur during the DlcDevKit builder process. These errors indicate missing required components when constructing a new DlcDevKit instance.
Error
The main error type for the DDK library that consolidates all possible errors that can occur throughout the project. This includes errors from:
LoggerError
Errors related to logging operations in DDK. Handles failures in:
ManagerError
Errors from the DLC Manager component. Currently wraps the underlying Rust-DLC manager errors.
OracleError
Errors related to oracle operations in DDK. Handles failures in:
StorageError
Errors related to storage operations in DDK. Handles failures in:
TransportError
Errors related to the transport layer in DDK. Handles failures in:
WalletError
Errors related to Bitcoin wallet operations. Handles failures in:

Functions

esplora_err_to_manager_err
Converts an Esplora error to a DLC manager error
to_storage_error
Converts a generic error to a DLC manager storage error
wallet_err_to_manager_err
Converts a wallet error to a DLC manager error