DDK error types
Enums
- Builder
Error - Errors that can occur during the DlcDevKit builder process. These errors indicate missing required components when constructing a new DlcDevKit instance.
- Error
- The main error type for the DDK library that consolidates all possible errors that can occur throughout the project. This includes errors from:
- Logger
Error - Errors related to logging operations in DDK. Handles failures in:
- Manager
Error - Errors from the DLC Manager component. Currently wraps the underlying Rust-DLC manager errors.
- Oracle
Error - Errors related to oracle operations in DDK. Handles failures in:
- Storage
Error - Errors related to storage operations in DDK. Handles failures in:
- Transport
Error - Errors related to the transport layer in DDK. Handles failures in:
- Wallet
Error - Errors related to Bitcoin wallet operations. Handles failures in:
Functions
- esplora_
err_ to_ manager_ err - Converts an Esplora error to a DLC manager error
- to_
storage_ error - Converts a generic error to a DLC manager storage error
- wallet_
err_ to_ manager_ err - Converts a wallet error to a DLC manager error